.. _geomai_projects:

GeomAIProjects
==============

.. py:module:: ansys.simai.core.data.geomai.projects

Projects are a selection of training data used to train a model.


Directory
---------

.. autoclass:: GeomAIProjectDirectory()
    :members:

Model
-----

.. autoclass:: GeomAIProject()
    :members:
    :inherited-members:
